| Title: | A VSCode skin for RStudio |
|---|---|
| Description: | It really just modifies RStudio presentation. |
| Authors: | Anthony North [aut, cre], Miles McBain [ctb] |
| Maintainer: | Anthony North <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-24 10:03:40 UTC |
| Source: | https://github.com/anthonynorth/rscodeio |
You'll need RStudio at least 1.2.x and if your RStudio is installed to a default location on Windows or Linux, you'll need to be running RStudio as Administrator to install the menu theme files (Just required for install).
install_theme(menus = TRUE)install_theme(menus = TRUE)
menus |
If FALSE, do not install the RStudio menu theme QSS files. |
You can elect not to install the menu theme files with 'menus = FALSE'.
Nothing.
Uninstall the rscodeio theme
uninstall_theme()uninstall_theme()
nothing.